@@ -70,12 +70,12 @@ class Client:
             res.append(data)
         return res
 
-    def sub(self, symbols: list, data_type: bytes, sub_handler):
+    def sub(self, symbols: list, data_type: bytes, sub_handler = None):
         for symbol in symbols:
             msub = message.Sub(symbol, data_type)
             self.send(msub)
             
-        while True:
+        while sub_handler:
             msubr = message.SubR()
             self.recv(msubr)
 
@@ -91,4 +91,4 @@ if __name__ == '__main__':
 
     datas = client.get(b'000001.SZ', b'stock', b'20211020093000000')
     for data in datas:
-        print(data)
\ No newline at end of file
+        print(data)
